/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management;

import javax.management.MBeanServer;
import javax.management.ObjectName;

import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.apache.camel.management.DefaultManagementObjectNameStrategy.TYPE_ENDPOINT;
import static org.junit.jupiter.api.Assertions.assertTrue;

public class ManagedEndpointExplainTest extends ManagementTestSupport {

    @Test
    public void testManageEndpointExplain() throws Exception {
        MBeanServer mbeanServer = getMBeanServer();

        ObjectName on = getCamelObjectName(TYPE_ENDPOINT, "seda://test");
        assertTrue(mbeanServer.isRegistered(on));

        on = getCamelObjectName(TYPE_ENDPOINT, "mock://result");
        assertTrue(mbeanServer.isRegistered(on));

        on = getCamelObjectName(TYPE_ENDPOINT, "log://foo\\?groupDelay=2000&groupSize=5&level=WARN");
        assertTrue(mbeanServer.isRegistered(on));
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("seda:test")
                        .to("log:foo?groupDelay=2000&groupSize=5&level=WARN")
                        .to("mock:result");
            }
        };
    }

}
